@@ -1,6 +1,7 @@
 import asyncio
 import datetime
 import json
+import logging
 import sys
 import time
 
@@ -9,10 +10,9 @@ import requests
 from pyrogram import Client
 
 from . import generals
+from .cog import Cog
 from .generals import RoleException
 from .objects import Message, ChatActions, UserProfilePicture, CallbackQuery, Command
-from .cog import Cog
-import logging
 
 
 class Bot:
@@ -33,6 +33,7 @@ class Bot:
         self.group_photos = []
         self.actions_from_cog = []
         self.command_roles = {}
+        self.ignore_listener_filter = []
         self.message_handlers = {}
         self.listeners_handle = {}
         self.aliases = {}
@@ -130,17 +131,19 @@ class Bot:
     def command(self, name,aliases=None,usage=None,description=None, roles=None, ignore_filter=False):
         def decorator(func):
             command = Command(func,name,description,aliases,usage,roles,ignore_filter)
-            self.add_message_handler(name, command)
+            self.add_command(name, command)
             if ignore_filter:
                 self.ignore_filter.append(command)
             if aliases is not None:
                 for al in aliases:
-                    self.aliases.update({al:command})
+                    self.add_command(al,command)
         return decorator
 
-    def listener(self):
+    def listener(self,ignore_filter=False):
         def decorator(func):
             self.add_listener(func.__name__, func)
+            if ignore_filter:
+                self.ignore_listener_filter.append(func)
 
         return decorator
 
@@ -150,9 +153,6 @@ class Bot:
         else:
             self.listeners_handle.update({name: [func]})
 
-    def add_message_handler(self, name, command):
-        self.add_command(name, command)
-
     async def dispacth_query(self, query):
         for _m in self.listeners_handle.get('on_callback_query'):
             if _m in self.actions_from_cog:
@@ -187,10 +187,11 @@ class Bot:
     async def dispatch_message(self, message):
         if self.listeners_handle.get('on_message_new'):
             for _m in self.listeners_handle.get('on_message_new'):
-                if _m in self.actions_from_cog:
-                    await _m(self, message)
-                else:
-                    await _m(message)
+                if _m in self.ignore_listener_filter or message.chat.id in self.chat_filter:
+                    if _m in self.actions_from_cog:
+                        await _m(self, message)
+                    else:
+                        await _m(message)
 
     async def dispatch_command(self, message, command):
         if command in self.actions_from_cog:
@@ -201,10 +202,11 @@ class Bot:
     async def dispatch_uknow_command(self, message):
         if self.listeners_handle.get("on_unknow_command"):
             for _m in self.listeners_handle.get('on_unknow_command'):
-                if _m in self.actions_from_cog:
-                    await _m(self,message)
-                else:
-                    await _m(message)
+                if _m in self.ignore_listener_filter or message.chat.id in self.chat_filter:
+                    if _m in self.actions_from_cog:
+                        await _m(self,message)
+                    else:
+                        await _m(message)
 
     async def dispath_group_photo(self, message):
         time.sleep(1)
@@ -217,10 +219,11 @@ class Bot:
         else:
             if self.listeners_handle.get('on_photo'):
                 for _m in self.listeners_handle.get('on_photo'):
-                    if _m in self.actions_from_cog:
-                        await _m(self, message)
-                    else:
-                        await _m(message)
+                    if _m in self.ignore_listener_filter or message.chat.id in self.chat_filter:
+                        if _m in self.actions_from_cog:
+                            await _m(self, message)
+                        else:
+                            await _m(message)
         self.group_photos = []
 
     async def dispatch_photo(self, message):
@@ -229,18 +232,20 @@ class Bot:
     async def dispatch_sticker(self, message):
         if self.listeners_handle.get('on_sticker_new'):
             for _m in self.listeners_handle.get('on_sticker_new'):
-                if _m in self.actions_from_cog:
-                    await _m(self, message)
-                else:
-                    await _m(message)
+                if _m in self.ignore_listener_filter or message.chat.id in self.chat_filter:
+                    if _m in self.actions_from_cog:
+                        await _m(self, message)
+                    else:
+                        await _m(message)
 
     async def dispatch_new_member(self, message):
         if self.listeners_handle.get('on_new_member'):
             for _m in self.listeners_handle.get('on_new_member'):
-                if _m in self.actions_from_cog:
-                    await _m(self, message)
-                else:
-                    await _m(message)
+                if _m in self.ignore_listener_filter or message.chat.id in self.chat_filter:
+                    if _m in self.actions_from_cog:
+                        await _m(self, message)
+                    else:
+                        await _m(message)
 
     async def dispatch_chat_filter_error(self,message):
         if self.listeners_handle.get('on_chat_filter'):
@@ -285,21 +290,23 @@ class Bot:
                 command = Command(v,v.__command__)
                 if 'description' in dir(v):
                     command.description = v.description
-                if 'aliases' in dir(v):
-                    command.aliases = v.aliases
-                    for al in v.aliases:
-                        self.aliases.update({al:command})
                 if 'usage' in dir(v):
                     command.usage = v.usage
                 if 'roles' in dir(v):
                     command.roles = v.roles
                 if v.__ignore_filter__:
                     self.ignore_filter.append(command)
-                self.add_message_handler(v.__command__, command)
+                if 'aliases' in dir(v):
+                    command.aliases = v.aliases
+                    for al in v.aliases:
+                        self.add_command(al,command)
+                self.add_command(v.__command__, command)
                 self.actions_from_cog.append(command)
             elif '__listener__' in dir(v):
                 self.add_listener(v.__listener__, v)
                 self.actions_from_cog.append(v)
+                if v.__ignore_filter__:
+                    self.ignore_listener_filter.append(v)
 
     async def dispatch(self, message):
         if self.has_prefix(message):
